@@ -1,25 +1,26 @@
-"""Custom middleware used by the pages application."""
+'''Custom middleware used by the pages application.'''
 
 import sys
 
 from django.conf import settings
-from django.core import urlresolvers
-from django.core.handlers.base import BaseHandler
+from django import urls
+from django.core.handlers.exception import handle_uncaught_exception
 from django.http import Http404
 from django.shortcuts import redirect
 from django.template.response import SimpleTemplateResponse
+from django.utils.deprecation import MiddlewareMixin
 from django.utils.functional import cached_property
 from django.views.debug import technical_404_response
 
 from cms.apps.pages.models import Page
 
 
-class RequestPageManager(object):
+class RequestPageManager:
 
-    """Handles loading page objects."""
+    '''Handles loading page objects.'''
 
     def __init__(self, request):
-        """Initializes the RequestPageManager."""
+        '''Initializes the RequestPageManager.'''
         self._request = request
         self._path = self._request.path
         self._path_info = self._request.path_info
@@ -38,6 +39,9 @@ class RequestPageManager(object):
         return None
 
     def alternate_page_version(self, page):
+        # Save ourselves a DB query if we are not using localisation.
+        if not self.country:
+            return page
 
         try:
             # See if the page has any alternate versions for the current country
@@ -54,22 +58,22 @@ class RequestPageManager(object):
 
     @cached_property
     def homepage(self):
-        """Returns the site homepage."""
+        '''Returns the site homepage.'''
         try:
             return Page.objects.get_homepage()
         except Page.DoesNotExist:
             return None
 
-    @property
+    @cached_property
     def is_homepage(self):
-        """Whether the current request is for the site homepage."""
+        '''Whether the current request is for the site homepage.'''
         return self._path == self.homepage.get_absolute_url()
 
     @cached_property
     def breadcrumbs(self):
-        """The breadcrumbs for the current request."""
+        '''The breadcrumbs for the current request.'''
         breadcrumbs = []
-        slugs = self._path_info.strip("/").split("/")
+        slugs = self._path_info.strip('/').split('/')
         slugs.reverse()
 
         def do_breadcrumbs(page):
@@ -84,49 +88,49 @@ class RequestPageManager(object):
             do_breadcrumbs(self.homepage)
         return breadcrumbs
 
-    @property
+    @cached_property
     def section(self):
-        """The current primary level section, or None."""
+        '''The current primary level section, or None.'''
         try:
             page = self.breadcrumbs[1]
             return self.alternate_page_version(page)
         except IndexError:
             return None
 
-    @property
+    @cached_property
     def subsection(self):
-        """The current secondary level section, or None."""
+        '''The current secondary level section, or None.'''
         try:
             page = self.breadcrumbs[2]
             return self.alternate_page_version(page)
         except IndexError:
             return None
 
-    @property
+    @cached_property
     def current(self):
-        """The current best-matched page."""
+        '''The current best-matched page.'''
         try:
             page = self.breadcrumbs[-1]
             return self.alternate_page_version(page)
         except IndexError:
             return None
 
-    @property
+    @cached_property
     def is_exact(self):
-        """Whether the current page exactly matches the request URL."""
+        '''Whether the current page exactly matches the request URL.'''
         return self.current.get_absolute_url() == self._path
 
 
-class PageMiddleware(object):
+class PageMiddleware(MiddlewareMixin):
 
-    """Serves up pages when no other view is matched."""
+    '''Serves up pages when no other view is matched.'''
 
     def process_request(self, request):
-        """Annotates the request with a page manager."""
+        '''Annotates the request with a page manager.'''
         request.pages = RequestPageManager(request)
 
     def process_response(self, request, response):
-        """If the response was a 404, attempt to serve up a page."""
+        '''If the response was a 404, attempt to serve up a page.'''
         if response.status_code != 404:
             return response
         # Get the current page.
@@ -149,15 +153,15 @@ class PageMiddleware(object):
         # Dispatch to the content.
         try:
             try:
-                callback, callback_args, callback_kwargs = urlresolvers.resolve(path_info, page.content.urlconf)
-            except urlresolvers.Resolver404:
+                callback, callback_args, callback_kwargs = urls.resolve(path_info, page.content.urlconf)
+            except urls.Resolver404:
                 # First of all see if adding a slash will help matters.
                 if settings.APPEND_SLASH:
-                    new_path_info = path_info + "/"
+                    new_path_info = path_info + '/'
 
                     try:
-                        urlresolvers.resolve(new_path_info, page.content.urlconf)
-                    except urlresolvers.Resolver404:
+                        urls.resolve(new_path_info, page.content.urlconf)
+                    except urls.Resolver404:
                         pass
                     else:
                         return redirect(script_name + new_path_info, permanent=True)
@@ -171,7 +175,7 @@ class PageMiddleware(object):
 
             if request:
                 if page.auth_required() and not request.user.is_authenticated():
-                    return redirect("{}?next={}".format(
+                    return redirect('{}?next={}'.format(
                         settings.LOGIN_URL,
                         request.path
                     ))
@@ -186,4 +190,4 @@ class PageMiddleware(object):
             # Let the normal 404 mechanisms render an error page.
             return response
         except:
-            return BaseHandler().handle_uncaught_exception(request, urlresolvers.get_resolver(None), sys.exc_info())
+            return handle_uncaught_exception(request, urls.get_resolver(None), sys.exc_info())
