@@ -1,4 +1,4 @@
-"""URLs used by the standard content page."""
+'''URLs used by ContentBase derivatives.'''
 
 from django.conf.urls import url
 from django.views.decorators.csrf import csrf_protect
@@ -6,5 +6,5 @@ from django.views.decorators.csrf import csrf_protect
 from cms.apps.pages import views
 
 urlpatterns = [
-    url(r"^$", csrf_protect(views.ContentIndexView.as_view()), name="index")
+    url(r'^$', csrf_protect(views.ContentIndexView.as_view()), name='index')
 ]
